# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bugs.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nbugs.proto\x12\x11org.couchers.bugs\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/httpbody.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"\x1e\n\x0bVersionInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\"1\n\x10ScreenResolution\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\"\xc1\x01\n\x0cReportBugReq\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07results\x18\x04 \x01(\t\x12\x18\n\x10\x66rontend_version\x18\x05 \x01(\t\x12\x12\n\nuser_agent\x18\x06 \x01(\t\x12\x0c\n\x04page\x18\x07 \x01(\t\x12>\n\x11screen_resolution\x18\x08 \x01(\x0b\x32#.org.couchers.bugs.ScreenResolution\"/\n\x0cReportBugRes\x12\x0e\n\x06\x62ug_id\x18\x02 \x01(\t\x12\x0f\n\x07\x62ug_url\x18\x03 \x01(\t\"\x1a\n\tStatusReq\x12\r\n\x05nonce\x18\x01 \x01(\t\"R\n\tStatusRes\x12\r\n\x05nonce\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x15\n\rcoucher_count\x18\x03 \x01(\x04\x12\x0e\n\x06stable\x18\x04 \x01(\x08\"\x84\x01\n\x18GeolocationSearchInfoReq\x12\x15\n\rsearch_string\x18\x01 \x01(\t\x12\x1d\n\x15nominatim_result_json\x18\x02 \x01(\t\x12\x1d\n\x15\x66ormatted_result_json\x18\x03 \x01(\t\x12\x13\n\x0b\x64uration_ms\x18\x04 \x01(\r\"e\n\x17GeolocationClickInfoReq\x12\x0f\n\x07\x63ontext\x18\x01 \x01(\t\x12\x1d\n\x15\x66ormatted_result_json\x18\x02 \x01(\t\x12\x1a\n\x12search_choice_json\x18\x03 \x01(\t\"s\n\x0e\x44iagnosticInfo\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x17\n\x0fproperties_json\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x01\x12,\n\x08occurred\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"b\n\x14ReportDiagnosticsReq\x12\x18\n\x10\x66rontend_version\x18\x01 \x01(\t\x12\x30\n\x05infos\x18\x02 \x03(\x0b\x32!.org.couchers.bugs.DiagnosticInfo\"\xaa\x06\n\x14\x43heckNativeStatusReq\x12\x12\n\ndebug_json\x18\x01 \x01(\t\x12\x15\n\reas_client_id\x18\x02 \x01(\t\x12\x12\n\ninstall_id\x18\x03 \x01(\t\x12\x11\n\tsticky_id\x18\x04 \x01(\t\x12\x0c\n\x04idfv\x18\x05 \x01(\t\x12\x12\n\nandroid_id\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x07 \x01(\t\x12\x10\n\x08platform\x18\x08 \x01(\t\x12\x12\n\nos_version\x18\t \x01(\t\x12\x0e\n\x06locale\x18\n \x01(\t\x12\x12\n\nuser_state\x18\x0b \x01(\t\x12\x13\n\x0b\x61pp_variant\x18\x0c \x01(\t\x12\x13\n\x0b\x61pp_version\x18\r \x01(\t\x12\x14\n\x0cnative_build\x18\x0e \x01(\t\x12 \n\x18\x65mbedded_display_version\x18\x0f \x01(\t\x12\x1e\n\x16\x65mbedded_debug_version\x18\x10 \x01(\t\x12\x1f\n\x17running_display_version\x18\x11 \x01(\t\x12\x1d\n\x15running_debug_version\x18\x12 \x01(\t\x12!\n\x19running_debug_version_ota\x18\x13 \x01(\t\x12\x17\n\x0fruntime_version\x18\x14 \x01(\t\x12\x11\n\tupdate_id\x18\x15 \x01(\t\x12\x1a\n\x12is_embedded_launch\x18\x16 \x01(\x08\x12\x15\n\rlaunch_source\x18\x17 \x01(\t\x12\x37\n\x13\x65mbedded_created_at\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0fpush_permission\x18\x1a \x01(\t\x12\x12\n\npush_token\x18\x1b \x01(\t\x12\x37\n\x14time_since_last_open\x18\x1c \x01(\x0b\x32\x19.google.protobuf.Duration\x12,\n\x08occurred\x18\x1d \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa3\x02\n\x10NativeUpdateInfo\x12\x35\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32%.org.couchers.bugs.NativeUpdateAction\x12\x10\n\x08required\x18\x02 \x01(\x08\x12*\n\x06\x61\x63t_by\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0cnag_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\x10\n\x08link_url\x18\x06 \x01(\t\x12\x11\n\tlink_text\x18\x07 \x01(\t\x12\x33\n\x05\x63\x61use\x18\x08 \x01(\x0e\x32$.org.couchers.bugs.NativeUpdateCause\"P\n\x14\x43heckNativeStatusRes\x12\x38\n\x0bupdate_info\x18\x01 \x01(\x0b\x32#.org.couchers.bugs.NativeUpdateInfo\"*\n\x16\x45valuateFeatureFlagReq\x12\x10\n\x08\x66lag_key\x18\x01 \x01(\t\"?\n\x16\x45valuateFeatureFlagRes\x12%\n\x05value\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Value\"\xe5\x02\n\x18LogExperimentExposureReq\x12\x16\n\x0e\x65xperiment_key\x18\x01 \x01(\t\x12\x17\n\x0f\x65xperiment_name\x18\x02 \x01(\t\x12\x14\n\x0cvariation_id\x18\x03 \x01(\x05\x12\x15\n\rvariation_key\x18\x04 \x01(\t\x12\x16\n\x0evariation_name\x18\x05 \x01(\t\x12\x16\n\x0ehash_attribute\x18\x06 \x01(\t\x12\x12\n\nhash_value\x18\x07 \x01(\t\x12\x12\n\nfeature_id\x18\x08 \x01(\t\x12\x15\n\rin_experiment\x18\t \x01(\x08\x12\x13\n\x06\x62ucket\x18\n \x01(\x01H\x00\x88\x01\x01\x12\x16\n\thash_used\x18\x0b \x01(\x08H\x01\x88\x01\x01\x12\x1f\n\x12sticky_bucket_used\x18\x0c \x01(\x08H\x02\x88\x01\x01\x42\t\n\x07_bucketB\x0c\n\n_hash_usedB\x15\n\x13_sticky_bucket_used*\xbb\x01\n\x12NativeUpdateAction\x12$\n NATIVE_UPDATE_ACTION_UNSPECIFIED\x10\x00\x12\x1d\n\x19NATIVE_UPDATE_ACTION_NONE\x10\x01\x12\x1c\n\x18NATIVE_UPDATE_ACTION_OTA\x10\x02\x12\x1e\n\x1aNATIVE_UPDATE_ACTION_STORE\x10\x03\x12\"\n\x1eNATIVE_UPDATE_ACTION_REINSTALL\x10\x04*u\n\x11NativeUpdateCause\x12#\n\x1fNATIVE_UPDATE_CAUSE_UNSPECIFIED\x10\x00\x12\x1b\n\x17NATIVE_UPDATE_CAUSE_AGE\x10\x01\x12\x1e\n\x1aNATIVE_UPDATE_CAUSE_BANNED\x10\x02\x32\x95\x08\n\x04\x42ugs\x12S\n\x07Version\x12\x16.google.protobuf.Empty\x1a\x1e.org.couchers.bugs.VersionInfo\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/version\x12O\n\tReportBug\x12\x1f.org.couchers.bugs.ReportBugReq\x1a\x1f.org.couchers.bugs.ReportBugRes\"\x00\x12U\n\x06Status\x12\x1c.org.couchers.bugs.StatusReq\x1a\x1c.org.couchers.bugs.StatusRes\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/status\x12W\n\x0eGetDescriptors\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/descriptors.pb\x12\x63\n\x17GetNativeUpdateManifest\x12\x14.google.api.HttpBody\x1a\x14.google.api.HttpBody\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/native/ota/manifest\x12^\n\x15GeolocationSearchInfo\x12+.org.couchers.bugs.GeolocationSearchInfoReq\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x14GeolocationClickInfo\x12*.org.couchers.bugs.GeolocationClickInfoReq\x1a\x16.google.protobuf.Empty\"\x00\x12V\n\x11ReportDiagnostics\x12\'.org.couchers.bugs.ReportDiagnosticsReq\x1a\x16.google.protobuf.Empty\"\x00\x12g\n\x11\x43heckNativeStatus\x12\'.org.couchers.bugs.CheckNativeStatusReq\x1a\'.org.couchers.bugs.CheckNativeStatusRes\"\x00\x12m\n\x13\x45valuateFeatureFlag\x12).org.couchers.bugs.EvaluateFeatureFlagReq\x1a).org.couchers.bugs.EvaluateFeatureFlagRes\"\x00\x12^\n\x15LogExperimentExposure\x12+.org.couchers.bugs.LogExperimentExposureReq\x1a\x16.google.protobuf.Empty\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bugs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BUGS']._loaded_options = None
  _globals['_BUGS']._serialized_options = b'\210\265\030\001'
  _globals['_BUGS'].methods_by_name['Version']._loaded_options = None
  _globals['_BUGS'].methods_by_name['Version']._serialized_options = b'\202\323\344\223\002\n\022\010/version'
  _globals['_BUGS'].methods_by_name['Status']._loaded_options = None
  _globals['_BUGS'].methods_by_name['Status']._serialized_options = b'\202\323\344\223\002\t\022\007/status'
  _globals['_BUGS'].methods_by_name['GetDescriptors']._loaded_options = None
  _globals['_BUGS'].methods_by_name['GetDescriptors']._serialized_options = b'\202\323\344\223\002\021\022\017/descriptors.pb'
  _globals['_BUGS'].methods_by_name['GetNativeUpdateManifest']._loaded_options = None
  _globals['_BUGS'].methods_by_name['GetNativeUpdateManifest']._serialized_options = b'\202\323\344\223\002\026\022\024/native/ota/manifest'
  _globals['_NATIVEUPDATEACTION']._serialized_start=2787
  _globals['_NATIVEUPDATEACTION']._serialized_end=2974
  _globals['_NATIVEUPDATECAUSE']._serialized_start=2976
  _globals['_NATIVEUPDATECAUSE']._serialized_end=3093
  _globals['_VERSIONINFO']._serialized_start=233
  _globals['_VERSIONINFO']._serialized_end=263
  _globals['_SCREENRESOLUTION']._serialized_start=265
  _globals['_SCREENRESOLUTION']._serialized_end=314
  _globals['_REPORTBUGREQ']._serialized_start=317
  _globals['_REPORTBUGREQ']._serialized_end=510
  _globals['_REPORTBUGRES']._serialized_start=512
  _globals['_REPORTBUGRES']._serialized_end=559
  _globals['_STATUSREQ']._serialized_start=561
  _globals['_STATUSREQ']._serialized_end=587
  _globals['_STATUSRES']._serialized_start=589
  _globals['_STATUSRES']._serialized_end=671
  _globals['_GEOLOCATIONSEARCHINFOREQ']._serialized_start=674
  _globals['_GEOLOCATIONSEARCHINFOREQ']._serialized_end=806
  _globals['_GEOLOCATIONCLICKINFOREQ']._serialized_start=808
  _globals['_GEOLOCATIONCLICKINFOREQ']._serialized_end=909
  _globals['_DIAGNOSTICINFO']._serialized_start=911
  _globals['_DIAGNOSTICINFO']._serialized_end=1026
  _globals['_REPORTDIAGNOSTICSREQ']._serialized_start=1028
  _globals['_REPORTDIAGNOSTICSREQ']._serialized_end=1126
  _globals['_CHECKNATIVESTATUSREQ']._serialized_start=1129
  _globals['_CHECKNATIVESTATUSREQ']._serialized_end=1939
  _globals['_NATIVEUPDATEINFO']._serialized_start=1942
  _globals['_NATIVEUPDATEINFO']._serialized_end=2233
  _globals['_CHECKNATIVESTATUSRES']._serialized_start=2235
  _globals['_CHECKNATIVESTATUSRES']._serialized_end=2315
  _globals['_EVALUATEFEATUREFLAGREQ']._serialized_start=2317
  _globals['_EVALUATEFEATUREFLAGREQ']._serialized_end=2359
  _globals['_EVALUATEFEATUREFLAGRES']._serialized_start=2361
  _globals['_EVALUATEFEATUREFLAGRES']._serialized_end=2424
  _globals['_LOGEXPERIMENTEXPOSUREREQ']._serialized_start=2427
  _globals['_LOGEXPERIMENTEXPOSUREREQ']._serialized_end=2784
  _globals['_BUGS']._serialized_start=3096
  _globals['_BUGS']._serialized_end=4141
# @@protoc_insertion_point(module_scope)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import events_pb2
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class EventsStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CreateEvent: grpc.UnaryUnaryMultiCallable[events_pb2.CreateEventReq, events_pb2.Event]
    """Creates an event, only one instance, add more with ScheduleEvent"""
    ScheduleEvent: grpc.UnaryUnaryMultiCallable[events_pb2.ScheduleEventReq, events_pb2.Event]
    """Schedules a new occurrence of an existing event"""
    UpdateEvent: grpc.UnaryUnaryMultiCallable[events_pb2.UpdateEventReq, events_pb2.Event]
    """Edit an event"""
    GetEvent: grpc.UnaryUnaryMultiCallable[events_pb2.GetEventReq, events_pb2.Event]
    """Gets an event"""
    CancelEvent: grpc.UnaryUnaryMultiCallable[events_pb2.CancelEventReq, google.protobuf.empty_pb2.Empty]
    """Cancels an event"""
    RequestCommunityInvite: grpc.UnaryUnaryMultiCallable[events_pb2.RequestCommunityInviteReq, google.protobuf.empty_pb2.Empty]
    """Requests that a notification/email invitation about the event is sent out to the community"""
    ListEventOccurrences: grpc.UnaryUnaryMultiCallable[events_pb2.ListEventOccurrencesReq, events_pb2.ListEventOccurrencesRes]
    """List all occurrences of a recurring event"""
    ListEventAttendees: grpc.UnaryUnaryMultiCallable[events_pb2.ListEventAttendeesReq, events_pb2.ListEventAttendeesRes]
    """Paginated list of event attendees"""
    ListEventSubscribers: grpc.UnaryUnaryMultiCallable[events_pb2.ListEventSubscribersReq, events_pb2.ListEventSubscribersRes]
    """Paginated list of event subscribers"""
    ListEventOrganizers: grpc.UnaryUnaryMultiCallable[events_pb2.ListEventOrganizersReq, events_pb2.ListEventOrganizersRes]
    """Paginated list of event organizers"""
    TransferEvent: grpc.UnaryUnaryMultiCallable[events_pb2.TransferEventReq, events_pb2.Event]
    """Transfer an event you own to either a group or a community"""
    SetEventSubscription: grpc.UnaryUnaryMultiCallable[events_pb2.SetEventSubscriptionReq, events_pb2.Event]
    """Subscribe to get notifications about all occurrences of an event"""
    SetEventAttendance: grpc.UnaryUnaryMultiCallable[events_pb2.SetEventAttendanceReq, events_pb2.Event]
    """RSVP/change going status for an occurrence of an event"""
    InviteEventOrganizer: grpc.UnaryUnaryMultiCallable[events_pb2.InviteEventOrganizerReq, google.protobuf.empty_pb2.Empty]
    """Invite another user to become an organizer of this event"""
    RemoveEventOrganizer: grpc.UnaryUnaryMultiCallable[events_pb2.RemoveEventOrganizerReq, google.protobuf.empty_pb2.Empty]
    """Remove yourself as an event organizer"""
    ListMyEvents: grpc.UnaryUnaryMultiCallable[events_pb2.ListMyEventsReq, events_pb2.ListMyEventsRes]
    """Lists all subscribed, attending"""
    ListAllEvents: grpc.UnaryUnaryMultiCallable[events_pb2.ListAllEventsReq, events_pb2.ListAllEventsRes]
    """Lists all events"""

class EventsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateEvent(
        self,
        request: events_pb2.CreateEventReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> events_pb2.Event:
        """Creates an event, only one instance, add more with ScheduleEvent"""

    @abc.abstractmethod
    def ScheduleEvent(
        self,
        request: events_pb2.ScheduleEventReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> events_pb2.Event:
        """Schedules a new occurrence of an existing event"""

    @abc.abstractmethod
    def UpdateEvent(
        self,
        request: events_pb2.UpdateEventReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> events_pb2.Event:
        """Edit an event"""

    @abc.abstractmethod
    def GetEvent(
        self,
        request: events_pb2.GetEventReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> events_pb2.Event:
        """Gets an event"""

    @abc.abstractmethod
    def CancelEvent(
        self,
        request: events_pb2.CancelEventReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Cancels an event"""

    @abc.abstractmethod
    def RequestCommunityInvite(
        self,
        request: events_pb2.RequestCommunityInviteReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Requests that a notification/email invitation about the event is sent out to the community"""

    @abc.abstractmethod
    def ListEventOccurrences(
        self,
        request: events_pb2.ListEventOccurrencesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> events_pb2.ListEventOccurrencesRes:
        """List all occurrences of a recurring event"""

    @abc.abstractmethod
    def ListEventAttendees(
        self,
        request: events_pb2.ListEventAttendeesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> events_pb2.ListEventAttendeesRes:
        """Paginated list of event attendees"""

    @abc.abstractmethod
    def ListEventSubscribers(
        self,
        request: events_pb2.ListEventSubscribersReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> events_pb2.ListEventSubscribersRes:
        """Paginated list of event subscribers"""

    @abc.abstractmethod
    def ListEventOrganizers(
        self,
        request: events_pb2.ListEventOrganizersReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> events_pb2.ListEventOrganizersRes:
        """Paginated list of event organizers"""

    @abc.abstractmethod
    def TransferEvent(
        self,
        request: events_pb2.TransferEventReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> events_pb2.Event:
        """Transfer an event you own to either a group or a community"""

    @abc.abstractmethod
    def SetEventSubscription(
        self,
        request: events_pb2.SetEventSubscriptionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> events_pb2.Event:
        """Subscribe to get notifications about all occurrences of an event"""

    @abc.abstractmethod
    def SetEventAttendance(
        self,
        request: events_pb2.SetEventAttendanceReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> events_pb2.Event:
        """RSVP/change going status for an occurrence of an event"""

    @abc.abstractmethod
    def InviteEventOrganizer(
        self,
        request: events_pb2.InviteEventOrganizerReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Invite another user to become an organizer of this event"""

    @abc.abstractmethod
    def RemoveEventOrganizer(
        self,
        request: events_pb2.RemoveEventOrganizerReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Remove yourself as an event organizer"""

    @abc.abstractmethod
    def ListMyEvents(
        self,
        request: events_pb2.ListMyEventsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> events_pb2.ListMyEventsRes:
        """Lists all subscribed, attending"""

    @abc.abstractmethod
    def ListAllEvents(
        self,
        request: events_pb2.ListAllEventsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> events_pb2.ListAllEventsRes:
        """Lists all events"""

def add_EventsServicer_to_server(servicer: EventsServicer, server: grpc.Server) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import groups_pb2 as groups__pb2


class GroupsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetGroup = channel.unary_unary(
                '/org.couchers.api.groups.Groups/GetGroup',
                request_serializer=groups__pb2.GetGroupReq.SerializeToString,
                response_deserializer=groups__pb2.Group.FromString,
                )
        self.ListAdmins = channel.unary_unary(
                '/org.couchers.api.groups.Groups/ListAdmins',
                request_serializer=groups__pb2.ListAdminsReq.SerializeToString,
                response_deserializer=groups__pb2.ListAdminsRes.FromString,
                )
        self.ListMembers = channel.unary_unary(
                '/org.couchers.api.groups.Groups/ListMembers',
                request_serializer=groups__pb2.ListMembersReq.SerializeToString,
                response_deserializer=groups__pb2.ListMembersRes.FromString,
                )
        self.ListPlaces = channel.unary_unary(
                '/org.couchers.api.groups.Groups/ListPlaces',
                request_serializer=groups__pb2.ListPlacesReq.SerializeToString,
                response_deserializer=groups__pb2.ListPlacesRes.FromString,
                )
        self.ListGuides = channel.unary_unary(
                '/org.couchers.api.groups.Groups/ListGuides',
                request_serializer=groups__pb2.ListGuidesReq.SerializeToString,
                response_deserializer=groups__pb2.ListGuidesRes.FromString,
                )
        self.ListEvents = channel.unary_unary(
                '/org.couchers.api.groups.Groups/ListEvents',
                request_serializer=groups__pb2.ListEventsReq.SerializeToString,
                response_deserializer=groups__pb2.ListEventsRes.FromString,
                )
        self.ListDiscussions = channel.unary_unary(
                '/org.couchers.api.groups.Groups/ListDiscussions',
                request_serializer=groups__pb2.ListDiscussionsReq.SerializeToString,
                response_deserializer=groups__pb2.ListDiscussionsRes.FromString,
                )
        self.JoinGroup = channel.unary_unary(
                '/org.couchers.api.groups.Groups/JoinGroup',
                request_serializer=groups__pb2.JoinGroupReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.LeaveGroup = channel.unary_unary(
                '/org.couchers.api.groups.Groups/LeaveGroup',
                request_serializer=groups__pb2.LeaveGroupReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListUserGroups = channel.unary_unary(
                '/org.couchers.api.groups.Groups/ListUserGroups',
                request_serializer=groups__pb2.ListUserGroupsReq.SerializeToString,
                response_deserializer=groups__pb2.ListUserGroupsRes.FromString,
                )


class GroupsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetGroup(self, request, context):
        """Get info about a group
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAdmins(self, request, context):
        """Gets a paginated list of group admins
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMembers(self, request, context):
        """Gets a paginated list of group members, including admins
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPlaces(self, request, context):
        """Returns a paginated list of places associated with a group
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListGuides(self, request, context):
        """Returns a paginated list of guides associated with a group
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEvents(self, request, context):
        """Returns a paginated events of guides associated with a group
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDiscussions(self, request, context):
        """Returns a paginated list of discussions associated with a group
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def JoinGroup(self, request, context):
        """Join a group

        Raises: FAILED_PRECONDITION if the user is already part of the group
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LeaveGroup(self, request, context):
        """Leave a group

        Raises: FAILED_PRECONDITION if the user is not part of the group
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserGroups(self, request, context):
        """Gets a list of groups a member belongs to
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GroupsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroup,
                    request_deserializer=groups__pb2.GetGroupReq.FromString,
                    response_serializer=groups__pb2.Group.SerializeToString,
            ),
            'ListAdmins': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAdmins,
                    request_deserializer=groups__pb2.ListAdminsReq.FromString,
                    response_serializer=groups__pb2.ListAdminsRes.SerializeToString,
            ),
            'ListMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMembers,
                    request_deserializer=groups__pb2.ListMembersReq.FromString,
                    response_serializer=groups__pb2.ListMembersRes.SerializeToString,
            ),
            'ListPlaces': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPlaces,
                    request_deserializer=groups__pb2.ListPlacesReq.FromString,
                    response_serializer=groups__pb2.ListPlacesRes.SerializeToString,
            ),
            'ListGuides': grpc.unary_unary_rpc_method_handler(
                    servicer.ListGuides,
                    request_deserializer=groups__pb2.ListGuidesReq.FromString,
                    response_serializer=groups__pb2.ListGuidesRes.SerializeToString,
            ),
            'ListEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEvents,
                    request_deserializer=groups__pb2.ListEventsReq.FromString,
                    response_serializer=groups__pb2.ListEventsRes.SerializeToString,
            ),
            'ListDiscussions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDiscussions,
                    request_deserializer=groups__pb2.ListDiscussionsReq.FromString,
                    response_serializer=groups__pb2.ListDiscussionsRes.SerializeToString,
            ),
            'JoinGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.JoinGroup,
                    request_deserializer=groups__pb2.JoinGroupReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'LeaveGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.LeaveGroup,
                    request_deserializer=groups__pb2.LeaveGroupReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListUserGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserGroups,
                    request_deserializer=groups__pb2.ListUserGroupsReq.FromString,
                    response_serializer=groups__pb2.ListUserGroupsRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.groups.Groups', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Groups(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.groups.Groups/GetGroup',
            groups__pb2.GetGroupReq.SerializeToString,
            groups__pb2.Group.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAdmins(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.groups.Groups/ListAdmins',
            groups__pb2.ListAdminsReq.SerializeToString,
            groups__pb2.ListAdminsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.groups.Groups/ListMembers',
            groups__pb2.ListMembersReq.SerializeToString,
            groups__pb2.ListMembersRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPlaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.groups.Groups/ListPlaces',
            groups__pb2.ListPlacesReq.SerializeToString,
            groups__pb2.ListPlacesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListGuides(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.groups.Groups/ListGuides',
            groups__pb2.ListGuidesReq.SerializeToString,
            groups__pb2.ListGuidesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.groups.Groups/ListEvents',
            groups__pb2.ListEventsReq.SerializeToString,
            groups__pb2.ListEventsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDiscussions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.groups.Groups/ListDiscussions',
            groups__pb2.ListDiscussionsReq.SerializeToString,
            groups__pb2.ListDiscussionsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def JoinGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.groups.Groups/JoinGroup',
            groups__pb2.JoinGroupReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LeaveGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.groups.Groups/LeaveGroup',
            groups__pb2.LeaveGroupReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.groups.Groups/ListUserGroups',
            groups__pb2.ListUserGroupsReq.SerializeToString,
            groups__pb2.ListUserGroupsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import moderation_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class ModerationStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetModerationQueue: grpc.UnaryUnaryMultiCallable[moderation_pb2.GetModerationQueueReq, moderation_pb2.GetModerationQueueRes]
    GetModerationState: grpc.UnaryUnaryMultiCallable[moderation_pb2.GetModerationStateReq, moderation_pb2.GetModerationStateRes]
    GetModerationLog: grpc.UnaryUnaryMultiCallable[moderation_pb2.GetModerationLogReq, moderation_pb2.GetModerationLogRes]
    ModerateContent: grpc.UnaryUnaryMultiCallable[moderation_pb2.ModerateContentReq, moderation_pb2.ModerateContentRes]
    SetUserContentVisibility: grpc.UnaryUnaryMultiCallable[moderation_pb2.SetUserContentVisibilityReq, moderation_pb2.SetUserContentVisibilityRes]
    ListModerationStates: grpc.UnaryUnaryMultiCallable[moderation_pb2.ListModerationStatesReq, moderation_pb2.ListModerationStatesRes]

class ModerationServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetModerationQueue(
        self,
        request: moderation_pb2.GetModerationQueueReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> moderation_pb2.GetModerationQueueRes: ...

    @abc.abstractmethod
    def GetModerationState(
        self,
        request: moderation_pb2.GetModerationStateReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> moderation_pb2.GetModerationStateRes: ...

    @abc.abstractmethod
    def GetModerationLog(
        self,
        request: moderation_pb2.GetModerationLogReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> moderation_pb2.GetModerationLogRes: ...

    @abc.abstractmethod
    def ModerateContent(
        self,
        request: moderation_pb2.ModerateContentReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> moderation_pb2.ModerateContentRes: ...

    @abc.abstractmethod
    def SetUserContentVisibility(
        self,
        request: moderation_pb2.SetUserContentVisibilityReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> moderation_pb2.SetUserContentVisibilityRes: ...

    @abc.abstractmethod
    def ListModerationStates(
        self,
        request: moderation_pb2.ListModerationStatesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> moderation_pb2.ListModerationStatesRes: ...

def add_ModerationServicer_to_server(servicer: ModerationServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import threads_pb2
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AttendanceState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AttendanceStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AttendanceState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ATTENDANCE_STATE_NOT_GOING: _AttendanceState.ValueType  # 0
    ATTENDANCE_STATE_GOING: _AttendanceState.ValueType  # 2
    """ATTENDANCE_STATE_MAYBE = 1; -- removed, maybe attendance is no longer supported"""

class AttendanceState(_AttendanceState, metaclass=_AttendanceStateEnumTypeWrapper): ...

ATTENDANCE_STATE_NOT_GOING: AttendanceState.ValueType  # 0
ATTENDANCE_STATE_GOING: AttendanceState.ValueType  # 2
"""ATTENDANCE_STATE_MAYBE = 1; -- removed, maybe attendance is no longer supported"""
Global___AttendanceState: typing_extensions.TypeAlias = AttendanceState

@typing.final
class EventLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    address: builtins.str
    """Events must have address + coordinates"""
    lat: builtins.float
    lng: builtins.float
    def __init__(
        self,
        *,
        address: builtins.str | None = ...,
        lat: builtins.float | None = ...,
        lng: builtins.float | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["address", b"address", "lat", b"lat", "lng", b"lng"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___EventLocation: typing_extensions.TypeAlias = EventLocation

@typing.final
class Event(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    IS_NEXT_FIELD_NUMBER: builtins.int
    IS_CANCELLED_FIELD_NUMBER: builtins.int
    IS_DELETED_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PHOTO_URL_FIELD_NUMBER: builtins.int
    PHOTO_KEY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    LAST_EDITED_FIELD_NUMBER: builtins.int
    CREATOR_USER_ID_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    ATTENDANCE_STATE_FIELD_NUMBER: builtins.int
    ORGANIZER_FIELD_NUMBER: builtins.int
    SUBSCRIBER_FIELD_NUMBER: builtins.int
    GOING_COUNT_FIELD_NUMBER: builtins.int
    ORGANIZER_COUNT_FIELD_NUMBER: builtins.int
    SUBSCRIBER_COUNT_FIELD_NUMBER: builtins.int
    OWNER_USER_ID_FIELD_NUMBER: builtins.int
    OWNER_COMMUNITY_ID_FIELD_NUMBER: builtins.int
    OWNER_GROUP_ID_FIELD_NUMBER: builtins.int
    THREAD_FIELD_NUMBER: builtins.int
    CAN_EDIT_FIELD_NUMBER: builtins.int
    CAN_MODERATE_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    """= occurrence_id"""
    is_next: builtins.bool
    """whether this is the next occurrence of this particular event
    e.g. if this is a recurring event
    """
    is_cancelled: builtins.bool
    is_deleted: builtins.bool
    title: builtins.str
    slug: builtins.str
    """a short URL fragment generated from the name, e.g. "New York City: weekly meetup" might become
    "new-york-city-weekly-meetup"
    """
    content: builtins.str
    """CommonMark without images"""
    photo_url: builtins.str
    """empty string if no photo"""
    photo_key: builtins.str
    creator_user_id: builtins.int
    timezone: builtins.str
    """the tzdata timezone identifier"""
    attendance_state: Global___AttendanceState.ValueType
    """the user's attendance state"""
    organizer: builtins.bool
    """whether the current user is a subscriber/organizer to the event
    subscribers get emails about stuff
    """
    subscriber: builtins.bool
    going_count: builtins.int
    organizer_count: builtins.int
    subscriber_count: builtins.int
    owner_user_id: builtins.int
    owner_community_id: builtins.int
    owner_group_id: builtins.int
    can_edit: builtins.bool
    can_moderate: builtins.bool
    @property
    def location(self) -> Global___EventLocation: ...
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_edited(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the UTC timestamps of start and end times"""

    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def thread(self) -> threads_pb2.Thread: ...
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
        is_next: builtins.bool | None = ...,
        is_cancelled: builtins.bool | None = ...,
        is_deleted: builtins.bool | None = ...,
        title: builtins.str | None = ...,
        slug: builtins.str | None = ...,
        content: builtins.str | None = ...,
        photo_url: builtins.str | None = ...,
        photo_key: builtins.str | None = ...,
        location: Global___EventLocation | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_edited: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        creator_user_id: builtins.int | None = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        timezone: builtins.str | None = ...,
        attendance_state: Global___AttendanceState.ValueType | None = ...,
        organizer: builtins.bool | None = ...,
        subscriber: builtins.bool | None = ...,
        going_count: builtins.int | None = ...,
        organizer_count: builtins.int | None = ...,
        subscriber_count: builtins.int | None = ...,
        owner_user_id: builtins.int | None = ...,
        owner_community_id: builtins.int | None = ...,
        owner_group_id: builtins.int | None = ...,
        thread: threads_pb2.Thread | None = ...,
        can_edit: builtins.bool | None = ...,
        can_moderate: builtins.bool | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["created", b"created", "end_time", b"end_time", "last_edited", b"last_edited", "location", b"location", "owner", b"owner", "owner_community_id", b"owner_community_id", "owner_group_id", b"owner_group_id", "owner_user_id", b"owner_user_id", "start_time", b"start_time", "thread", b"thread"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["attendance_state", b"attendance_state", "can_edit", b"can_edit", "can_moderate", b"can_moderate", "content", b"content", "created", b"created", "creator_user_id", b"creator_user_id", "end_time", b"end_time", "event_id", b"event_id", "going_count", b"going_count", "is_cancelled", b"is_cancelled", "is_deleted", b"is_deleted", "is_next", b"is_next", "last_edited", b"last_edited", "location", b"location", "organizer", b"organizer", "organizer_count", b"organizer_count", "owner", b"owner", "owner_community_id", b"owner_community_id", "owner_group_id", b"owner_group_id", "owner_user_id", b"owner_user_id", "photo_key", b"photo_key", "photo_url", b"photo_url", "slug", b"slug", "start_time", b"start_time", "subscriber", b"subscriber", "subscriber_count", b"subscriber_count", "thread", b"thread", "timezone", b"timezone", "title", b"title"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_owner: typing_extensions.TypeAlias = typing.Literal["owner_user_id", "owner_community_id", "owner_group_id"]
    _WhichOneofArgType_owner: typing_extensions.TypeAlias = typing.Literal["owner", b"owner"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType_owner) -> _WhichOneofReturnType_owner | None: ...

Global___Event: typing_extensions.TypeAlias = Event

@typing.final
class CreateEventReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PHOTO_KEY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    PARENT_COMMUNITY_ID_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    title: builtins.str
    content: builtins.str
    """CommonMark without images"""
    photo_key: builtins.str
    """from media server"""
    parent_community_id: builtins.int
    """Optional, can be auto-filled from the location"""
    timezone: builtins.str
    """the tzdata timezone identifier, empty string means tz of creating user"""
    @property
    def location(self) -> Global___EventLocation: ...
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """timestamps are in UTC"""

    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        title: builtins.str | None = ...,
        content: builtins.str | None = ...,
        photo_key: builtins.str | None = ...,
        location: Global___EventLocation | None = ...,
        parent_community_id: builtins.int | None = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        timezone: builtins.str | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["end_time", b"end_time", "location", b"location", "start_time", b"start_time"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["content", b"content", "end_time", b"end_time", "location", b"location", "parent_community_id", b"parent_community_id", "photo_key", b"photo_key", "start_time", b"start_time", "timezone", b"timezone", "title", b"title"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreateEventReq: typing_extensions.TypeAlias = CreateEventReq

@typing.final
class ScheduleEventReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PHOTO_KEY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    content: builtins.str
    """CommonMark without images"""
    photo_key: builtins.str
    """from media server"""
    timezone: builtins.str
    """the tzdata timezone identifier, empty string means tz of creating user"""
    @property
    def location(self) -> Global___EventLocation: ...
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """timestamps are in UTC"""

    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
        content: builtins.str | None = ...,
        photo_key: builtins.str | None = ...,
        location: Global___EventLocation | None = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        timezone: builtins.str | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["end_time", b"end_time", "location", b"location", "start_time", b"start_time"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["content", b"content", "end_time", b"end_time", "event_id", b"event_id", "location", b"location", "photo_key", b"photo_key", "start_time", b"start_time", "timezone", b"timezone"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ScheduleEventReq: typing_extensions.TypeAlias = ScheduleEventReq

@typing.final
class UpdateEventReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    UPDATE_ALL_FUTURE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PHOTO_KEY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    SHOULD_NOTIFY_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    update_all_future: builtins.bool
    """whether to update all future occurrences or just this one"""
    should_notify: builtins.bool
    """whether to notify all attendees about the change"""
    @property
    def title(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def content(self) -> google.protobuf.wrappers_pb2.StringValue:
        """CommonMark without images"""

    @property
    def photo_key(self) -> google.protobuf.wrappers_pb2.StringValue:
        """from media server, set to empty string to clear"""

    @property
    def location(self) -> Global___EventLocation: ...
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def timezone(self) -> google.protobuf.wrappers_pb2.StringValue:
        """the tzdata timezone identifier"""

    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
        update_all_future: builtins.bool | None = ...,
        title: google.protobuf.wrappers_pb2.StringValue | None = ...,
        content: google.protobuf.wrappers_pb2.StringValue | None = ...,
        photo_key: google.protobuf.wrappers_pb2.StringValue | None = ...,
        location: Global___EventLocation | None = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        timezone: google.protobuf.wrappers_pb2.StringValue | None = ...,
        should_notify: builtins.bool | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["content", b"content", "end_time", b"end_time", "location", b"location", "photo_key", b"photo_key", "start_time", b"start_time", "timezone", b"timezone", "title", b"title"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["content", b"content", "end_time", b"end_time", "event_id", b"event_id", "location", b"location", "photo_key", b"photo_key", "should_notify", b"should_notify", "start_time", b"start_time", "timezone", b"timezone", "title", b"title", "update_all_future", b"update_all_future"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateEventReq: typing_extensions.TypeAlias = UpdateEventReq

@typing.final
class GetEventReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["event_id", b"event_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetEventReq: typing_extensions.TypeAlias = GetEventReq

@typing.final
class CancelEventReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["event_id", b"event_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CancelEventReq: typing_extensions.TypeAlias = CancelEventReq

@typing.final
class RequestCommunityInviteReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["event_id", b"event_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RequestCommunityInviteReq: typing_extensions.TypeAlias = RequestCommunityInviteReq

@typing.final
class ListEventAttendeesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["event_id", b"event_id", "page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventAttendeesReq: typing_extensions.TypeAlias = ListEventAttendeesReq

@typing.final
class ListEventAttendeesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTENDEE_USER_IDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def attendee_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        attendee_user_ids: collections.abc.Iterable[builtins.int] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["attendee_user_ids", b"attendee_user_ids", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventAttendeesRes: typing_extensions.TypeAlias = ListEventAttendeesRes

@typing.final
class ListEventSubscribersReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["event_id", b"event_id", "page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventSubscribersReq: typing_extensions.TypeAlias = ListEventSubscribersReq

@typing.final
class ListEventSubscribersRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBSCRIBER_USER_IDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def subscriber_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        subscriber_user_ids: collections.abc.Iterable[builtins.int] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["next_page_token", b"next_page_token", "subscriber_user_ids", b"subscriber_user_ids"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventSubscribersRes: typing_extensions.TypeAlias = ListEventSubscribersRes

@typing.final
class ListEventOrganizersReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["event_id", b"event_id", "page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventOrganizersReq: typing_extensions.TypeAlias = ListEventOrganizersReq

@typing.final
class ListEventOrganizersRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZER_USER_IDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def organizer_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        organizer_user_ids: collections.abc.Iterable[builtins.int] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["next_page_token", b"next_page_token", "organizer_user_ids", b"organizer_user_ids"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventOrganizersRes: typing_extensions.TypeAlias = ListEventOrganizersRes

@typing.final
class ListMyEventsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAST_FIELD_NUMBER: builtins.int
    SUBSCRIBED_FIELD_NUMBER: builtins.int
    ATTENDING_FIELD_NUMBER: builtins.int
    ORGANIZING_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    MY_COMMUNITIES_FIELD_NUMBER: builtins.int
    INCLUDE_CANCELLED_FIELD_NUMBER: builtins.int
    MY_COMMUNITIES_EXCLUDE_GLOBAL_FIELD_NUMBER: builtins.int
    EXCLUDE_ATTENDING_FIELD_NUMBER: builtins.int
    past: builtins.bool
    """whether to paginate backwards"""
    subscribed: builtins.bool
    """all false => everything"""
    attending: builtins.bool
    organizing: builtins.bool
    page_size: builtins.int
    page_token: builtins.str
    page_number: builtins.int
    my_communities: builtins.bool
    """include events in the user's communities"""
    include_cancelled: builtins.bool
    my_communities_exclude_global: builtins.bool
    """when my_communities is set, exclude events in communities that are too large (e.g., the Global Community)"""
    exclude_attending: builtins.bool
    """exclude events the current user is already attending or organizing"""
    def __init__(
        self,
        *,
        past: builtins.bool | None = ...,
        subscribed: builtins.bool | None = ...,
        attending: builtins.bool | None = ...,
        organizing: builtins.bool | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        page_number: builtins.int | None = ...,
        my_communities: builtins.bool | None = ...,
        include_cancelled: builtins.bool | None = ...,
        my_communities_exclude_global: builtins.bool | None = ...,
        exclude_attending: builtins.bool | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["page_number", b"page_number", "page_token", b"page_token", "pagination", b"pagination"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["attending", b"attending", "exclude_attending", b"exclude_attending", "include_cancelled", b"include_cancelled", "my_communities", b"my_communities", "my_communities_exclude_global", b"my_communities_exclude_global", "organizing", b"organizing", "page_number", b"page_number", "page_size", b"page_size", "page_token", b"page_token", "pagination", b"pagination", "past", b"past", "subscribed", b"subscribed"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_pagination: typing_extensions.TypeAlias = typing.Literal["page_token", "page_number"]
    _WhichOneofArgType_pagination: typing_extensions.TypeAlias = typing.Literal["pagination", b"pagination"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType_pagination) -> _WhichOneofReturnType_pagination | None: ...

Global___ListMyEventsReq: typing_extensions.TypeAlias = ListMyEventsReq

@typing.final
class ListMyEventsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_ITEMS_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    total_items: builtins.int
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Event]: ...
    def __init__(
        self,
        *,
        events: collections.abc.Iterable[Global___Event] | None = ...,
        next_page_token: builtins.str | None = ...,
        total_items: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["events", b"events", "next_page_token", b"next_page_token", "total_items", b"total_items"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListMyEventsRes: typing_extensions.TypeAlias = ListMyEventsRes

@typing.final
class ListAllEventsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAST_FIELD_NUMBER: builtins.int
    INCLUDE_CANCELLED_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    past: builtins.bool
    """whether to paginate backwards"""
    include_cancelled: builtins.bool
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        past: builtins.bool | None = ...,
        include_cancelled: builtins.bool | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["include_cancelled", b"include_cancelled", "page_size", b"page_size", "page_token", b"page_token", "past", b"past"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListAllEventsReq: typing_extensions.TypeAlias = ListAllEventsReq

@typing.final
class ListAllEventsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Event]: ...
    def __init__(
        self,
        *,
        events: collections.abc.Iterable[Global___Event] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["events", b"events", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListAllEventsRes: typing_extensions.TypeAlias = ListAllEventsRes

@typing.final
class ListEventOccurrencesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    PAST_FIELD_NUMBER: builtins.int
    INCLUDE_CANCELLED_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    past: builtins.bool
    """whether to paginate backwards"""
    include_cancelled: builtins.bool
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
        past: builtins.bool | None = ...,
        include_cancelled: builtins.bool | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["event_id", b"event_id", "include_cancelled", b"include_cancelled", "page_size", b"page_size", "page_token", b"page_token", "past", b"past"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventOccurrencesReq: typing_extensions.TypeAlias = ListEventOccurrencesReq

@typing.final
class ListEventOccurrencesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Event]: ...
    def __init__(
        self,
        *,
        events: collections.abc.Iterable[Global___Event] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["events", b"events", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventOccurrencesRes: typing_extensions.TypeAlias = ListEventOccurrencesRes

@typing.final
class TransferEventReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    NEW_OWNER_COMMUNITY_ID_FIELD_NUMBER: builtins.int
    NEW_OWNER_GROUP_ID_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    new_owner_community_id: builtins.int
    new_owner_group_id: builtins.int
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
        new_owner_community_id: builtins.int | None = ...,
        new_owner_group_id: builtins.int | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["new_owner", b"new_owner", "new_owner_community_id", b"new_owner_community_id", "new_owner_group_id", b"new_owner_group_id"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["event_id", b"event_id", "new_owner", b"new_owner", "new_owner_community_id", b"new_owner_community_id", "new_owner_group_id", b"new_owner_group_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_new_owner: typing_extensions.TypeAlias = typing.Literal["new_owner_community_id", "new_owner_group_id"]
    _WhichOneofArgType_new_owner: typing_extensions.TypeAlias = typing.Literal["new_owner", b"new_owner"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType_new_owner) -> _WhichOneofReturnType_new_owner | None: ...

Global___TransferEventReq: typing_extensions.TypeAlias = TransferEventReq

@typing.final
class SetEventSubscriptionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    SUBSCRIBE_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    subscribe: builtins.bool
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
        subscribe: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["event_id", b"event_id", "subscribe", b"subscribe"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SetEventSubscriptionReq: typing_extensions.TypeAlias = SetEventSubscriptionReq

@typing.final
class SetEventAttendanceReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    ATTENDANCE_STATE_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    attendance_state: Global___AttendanceState.ValueType
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
        attendance_state: Global___AttendanceState.ValueType | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["attendance_state", b"attendance_state", "event_id", b"event_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SetEventAttendanceReq: typing_extensions.TypeAlias = SetEventAttendanceReq

@typing.final
class InviteEventOrganizerReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    user_id: builtins.int
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
        user_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["event_id", b"event_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___InviteEventOrganizerReq: typing_extensions.TypeAlias = InviteEventOrganizerReq

@typing.final
class RemoveEventOrganizerReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    @property
    def user_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        event_id: builtins.int | None = ...,
        user_id: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["user_id", b"user_id"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["event_id", b"event_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RemoveEventOrganizerReq: typing_extensions.TypeAlias = RemoveEventOrganizerReq



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import public_trips_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class PublicTripsStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CreatePublicTrip: grpc.UnaryUnaryMultiCallable[public_trips_pb2.CreatePublicTripReq, public_trips_pb2.PublicTrip]
    """Create a new public trip in a community"""
    GetPublicTrip: grpc.UnaryUnaryMultiCallable[public_trips_pb2.GetPublicTripReq, public_trips_pb2.PublicTrip]
    """Get details of a public trip"""
    ListPublicTrips: grpc.UnaryUnaryMultiCallable[public_trips_pb2.ListPublicTripsReq, public_trips_pb2.ListPublicTripsRes]
    """List public trips in a community (for hosts browsing)"""
    ListPublicTripsByUser: grpc.UnaryUnaryMultiCallable[public_trips_pb2.ListPublicTripsByUserReq, public_trips_pb2.ListPublicTripsByUserRes]
    """List a user's public trips. Used for both the user's own dashboard and
    for showing upcoming trips on another user's profile.
    - If user_id matches the caller, all trips (including closed/past) are returned.
    - Otherwise only active, upcoming trips are returned.
    """
    UpdatePublicTrip: grpc.UnaryUnaryMultiCallable[public_trips_pb2.UpdatePublicTripReq, public_trips_pb2.PublicTrip]
    """Edit a public trip. Owner-only. Content edits (dates, description)
    require the trip's end date to be today or later. Status can be set to
    CLOSED at any time, or back to SEARCHING_FOR_HOST as long as the trip is
    not in the past.
    """

class PublicTripsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreatePublicTrip(
        self,
        request: public_trips_pb2.CreatePublicTripReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> public_trips_pb2.PublicTrip:
        """Create a new public trip in a community"""

    @abc.abstractmethod
    def GetPublicTrip(
        self,
        request: public_trips_pb2.GetPublicTripReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> public_trips_pb2.PublicTrip:
        """Get details of a public trip"""

    @abc.abstractmethod
    def ListPublicTrips(
        self,
        request: public_trips_pb2.ListPublicTripsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> public_trips_pb2.ListPublicTripsRes:
        """List public trips in a community (for hosts browsing)"""

    @abc.abstractmethod
    def ListPublicTripsByUser(
        self,
        request: public_trips_pb2.ListPublicTripsByUserReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> public_trips_pb2.ListPublicTripsByUserRes:
        """List a user's public trips. Used for both the user's own dashboard and
        for showing upcoming trips on another user's profile.
        - If user_id matches the caller, all trips (including closed/past) are returned.
        - Otherwise only active, upcoming trips are returned.
        """

    @abc.abstractmethod
    def UpdatePublicTrip(
        self,
        request: public_trips_pb2.UpdatePublicTripReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> public_trips_pb2.PublicTrip:
        """Edit a public trip. Owner-only. Content edits (dates, description)
        require the trip's end date to be today or later. Status can be set to
        CLOSED at any time, or back to SEARCHING_FOR_HOST as long as the trip is
        not in the past.
        """

def add_PublicTripsServicer_to_server(servicer: PublicTripsServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2020 Google LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Http(google.protobuf.message.Message):
    """Defines the HTTP configuration for an API service. It contains a list of
    [HttpRule][google.api.HttpRule], each specifying the mapping of an RPC method
    to one or more HTTP REST API methods.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULES_FIELD_NUMBER: builtins.int
    FULLY_DECODE_RESERVED_EXPANSION_FIELD_NUMBER: builtins.int
    fully_decode_reserved_expansion: builtins.bool
    """When set to true, URL path parameters will be fully URI-decoded except in
    cases of single segment matches in reserved expansion, where "%2F" will be
    left encoded.

    The default behavior is to not decode RFC 6570 reserved characters in multi
    segment matches.
    """
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___HttpRule]:
        """A list of HTTP configuration rules that apply to individual API methods.

        **NOTE:** All service configuration rules follow "last one wins" order.
        """

    def __init__(
        self,
        *,
        rules: collections.abc.Iterable[Global___HttpRule] | None = ...,
        fully_decode_reserved_expansion: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["fully_decode_reserved_expansion", b"fully_decode_reserved_expansion", "rules", b"rules"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Http: typing_extensions.TypeAlias = Http

@typing.final
class HttpRule(google.protobuf.message.Message):
    """# gRPC Transcoding

    gRPC Transcoding is a feature for mapping between a gRPC method and one or
    more HTTP REST endpoints. It allows developers to build a single API service
    that supports both gRPC APIs and REST APIs. Many systems, including [Google
    APIs](https://github.com/googleapis/googleapis),
    [Cloud Endpoints](https://cloud.google.com/endpoints), [gRPC
    Gateway](https://github.com/grpc-ecosystem/grpc-gateway),
    and [Envoy](https://github.com/envoyproxy/envoy) proxy support this feature
    and use it for large scale production services.

    `HttpRule` defines the schema of the gRPC/REST mapping. The mapping specifies
    how different portions of the gRPC request message are mapped to the URL
    path, URL query parameters, and HTTP request body. It also controls how the
    gRPC response message is mapped to the HTTP response body. `HttpRule` is
    typically specified as an `google.api.http` annotation on the gRPC method.

    Each mapping specifies a URL path template and an HTTP method. The path
    template may refer to one or more fields in the gRPC request message, as long
    as each field is a non-repeated field with a primitive (non-message) type.
    The path template controls how fields of the request message are mapped to
    the URL path.

    Example:

        service Messaging {
          rpc GetMessage(GetMessageRequest) returns (Message) {
            option (google.api.http) = {
                get: "/v1/{name=messages/*}"
            };
          }
        }
        message GetMessageRequest {
          string name = 1; // Mapped to URL path.
        }
        message Message {
          string text = 1; // The resource content.
        }

    This enables an HTTP REST to gRPC mapping as below:

    HTTP | gRPC
    -----|-----
    `GET /v1/messages/123456`  | `GetMessage(name: "messages/123456")`

    Any fields in the request message which are not bound by the path template
    automatically become HTTP query parameters if there is no HTTP request body.
    For example:

        service Messaging {
          rpc GetMessage(GetMessageRequest) returns (Message) {
            option (google.api.http) = {
                get:"/v1/messages/{message_id}"
            };
          }
        }
        message GetMessageRequest {
          message SubMessage {
            string subfield = 1;
          }
          string message_id = 1; // Mapped to URL path.
          int64 revision = 2;    // Mapped to URL query parameter `revision`.
          SubMessage sub = 3;    // Mapped to URL query parameter `sub.subfield`.
        }

    This enables a HTTP JSON to RPC mapping as below:

    HTTP | gRPC
    -----|-----
    `GET /v1/messages/123456?revision=2&sub.subfield=foo` |
    `GetMessage(message_id: "123456" revision: 2 sub: SubMessage(subfield:
    "foo"))`

    Note that fields which are mapped to URL query parameters must have a
    primitive type or a repeated primitive type or a non-repeated message type.
    In the case of a repeated type, the parameter can be repeated in the URL
    as `...?param=A&param=B`. In the case of a message type, each field of the
    message is mapped to a separate parameter, such as
    `...?foo.a=A&foo.b=B&foo.c=C`.

    For HTTP methods that allow a request body, the `body` field
    specifies the mapping. Consider a REST update method on the
    message resource collection:

        service Messaging {
          rpc UpdateMessage(UpdateMessageRequest) returns (Message) {
            option (google.api.http) = {
              patch: "/v1/messages/{message_id}"
              body: "message"
            };
          }
        }
        message UpdateMessageRequest {
          string message_id = 1; // mapped to the URL
          Message message = 2;   // mapped to the body
        }

    The following HTTP JSON to RPC mapping is enabled, where the
    representation of the JSON in the request body is determined by
    protos JSON encoding:

    HTTP | gRPC
    -----|-----
    `PATCH /v1/messages/123456 { "text": "Hi!" }` | `UpdateMessage(message_id:
    "123456" message { text: "Hi!" })`

    The special name `*` can be used in the body mapping to define that
    every field not bound by the path template should be mapped to the
    request body.  This enables the following alternative definition of
    the update method:

        service Messaging {
          rpc UpdateMessage(Message) returns (Message) {
            option (google.api.http) = {
              patch: "/v1/messages/{message_id}"
              body: "*"
            };
          }
        }
        message Message {
          string message_id = 1;
          string text = 2;
        }


    The following HTTP JSON to RPC mapping is enabled:

    HTTP | gRPC
    -----|-----
    `PATCH /v1/messages/123456 { "text": "Hi!" }` | `UpdateMessage(message_id:
    "123456" text: "Hi!")`

    Note that when using `*` in the body mapping, it is not possible to
    have HTTP parameters, as all fields not bound by the path end in
    the body. This makes this option more rarely used in practice when
    defining REST APIs. The common usage of `*` is in custom methods
    which don't use the URL at all for transferring data.

    It is possible to define multiple HTTP methods for one RPC by using
    the `additional_bindings` option. Example:

        service Messaging {
          rpc GetMessage(GetMessageRequest) returns (Message) {
            option (google.api.http) = {
              get: "/v1/messages/{message_id}"
              additional_bindings {
                get: "/v1/users/{user_id}/messages/{message_id}"
              }
            };
          }
        }
        message GetMessageRequest {
          string message_id = 1;
          string user_id = 2;
        }

    This enables the following two alternative HTTP JSON to RPC mappings:

    HTTP | gRPC
    -----|-----
    `GET /v1/messages/123456` | `GetMessage(message_id: "123456")`
    `GET /v1/users/me/messages/123456` | `GetMessage(user_id: "me" message_id:
    "123456")`

    ## Rules for HTTP mapping

    1. Leaf request fields (recursive expansion nested messages in the request
       message) are classified into three categories:
       - Fields referred by the path template. They are passed via the URL path.
       - Fields referred by the [HttpRule.body][google.api.HttpRule.body]. They are passed via the HTTP
         request body.
       - All other fields are passed via the URL query parameters, and the
         parameter name is the field path in the request message. A repeated
         field can be represented as multiple query parameters under the same
         name.
     2. If [HttpRule.body][google.api.HttpRule.body] is "*", there is no URL query parameter, all fields
        are passed via URL path and HTTP request body.
     3. If [HttpRule.body][google.api.HttpRule.body] is omitted, there is no HTTP request body, all
        fields are passed via URL path and URL query parameters.

    ### Path template syntax

        Template = "/" Segments [ Verb ] ;
        Segments = Segment { "/" Segment } ;
        Segment  = "*" | "**" | LITERAL | Variable ;
        Variable = "{" FieldPath [ "=" Segments ] "}" ;
        FieldPath = IDENT { "." IDENT } ;
        Verb     = ":" LITERAL ;

    The syntax `*` matches a single URL path segment. The syntax `**` matches
    zero or more URL path segments, which must be the last part of the URL path
    except the `Verb`.

    The syntax `Variable` matches part of the URL path as specified by its
    template. A variable template must not contain other variables. If a variable
    matches a single path segment, its template may be omitted, e.g. `{var}`
    is equivalent to `{var=*}`.

    The syntax `LITERAL` matches literal text in the URL path. If the `LITERAL`
    contains any reserved character, such characters should be percent-encoded
    before the matching.

    If a variable contains exactly one path segment, such as `"{var}"` or
    `"{var=*}"`, when such a variable is expanded into a URL path on the client
    side, all characters except `[-_.~0-9a-zA-Z]` are percent-encoded. The
    server side does the reverse decoding. Such variables show up in the
    [Discovery
    Document](https://developers.google.com/discovery/v1/reference/apis) as
    `{var}`.

    If a variable contains multiple path segments, such as `"{var=foo/*}"`
    or `"{var=**}"`, when such a variable is expanded into a URL path on the
    client side, all characters except `[-_.~/0-9a-zA-Z]` are percent-encoded.
    The server side does the reverse decoding, except "%2F" and "%2f" are left
    unchanged. Such variables show up in the
    [Discovery
    Document](https://developers.google.com/discovery/v1/reference/apis) as
    `{+var}`.

    ## Using gRPC API Service Configuration

    gRPC API Service Configuration (service config) is a configuration language
    for configuring a gRPC service to become a user-facing product. The
    service config is simply the YAML representation of the `google.api.Service`
    proto message.

    As an alternative to annotating your proto file, you can configure gRPC
    transcoding in your service config YAML files. You do this by specifying a
    `HttpRule` that maps the gRPC method to a REST endpoint, achieving the same
    effect as the proto annotation. This can be particularly useful if you
    have a proto that is reused in multiple services. Note that any transcoding
    specified in the service config will override any matching transcoding
    configuration in the proto.

    Example:

        http:
          rules:
            # Selects a gRPC method and applies HttpRule to it.
            - selector: example.v1.Messaging.GetMessage
              get: /v1/messages/{message_id}/{sub.subfield}

    ## Special notes

    When gRPC Transcoding is used to map a gRPC to JSON REST endpoints, the
    proto to JSON conversion must follow the [proto3
    specification](https://developers.google.com/protocol-buffers/docs/proto3#json).

    While the single segment variable follows the semantics of
    [RFC 6570](https://tools.ietf.org/html/rfc6570) Section 3.2.2 Simple String
    Expansion, the multi segment variable **does not** follow RFC 6570 Section
    3.2.3 Reserved Expansion. The reason is that the Reserved Expansion
    does not expand special characters like `?` and `#`, which would lead
    to invalid URLs. As the result, gRPC Transcoding uses a custom encoding
    for multi segment variables.

    The path variables **must not** refer to any repeated or mapped field,
    because client libraries are not capable of handling such variable expansion.

    The path variables **must not** capture the leading "/" character. The reason
    is that the most common use case "{var}" does not capture the leading "/"
    character. For consistency, all path variables must share the same behavior.

    Repeated message fields must not be mapped to URL query parameters, because
    no client library can support such complicated mapping.

    If an API needs to use a JSON array for request or response body, it can map
    the request or response body to a repeated field. However, some gRPC
    Transcoding implementations may not support this feature.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SELECTOR_FIELD_NUMBER: builtins.int
    GET_FIELD_NUMBER: builtins.int
    PUT_FIELD_NUMBER: builtins.int
    POST_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    PATCH_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    RESPONSE_BODY_FIELD_NUMBER: builtins.int
    ADDITIONAL_BINDINGS_FIELD_NUMBER: builtins.int
    selector: builtins.str
    """Selects a method to which this rule applies.

    Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
    """
    get: builtins.str
    """Maps to HTTP GET. Used for listing and getting information about
    resources.
    """
    put: builtins.str
    """Maps to HTTP PUT. Used for replacing a resource."""
    post: builtins.str
    """Maps to HTTP POST. Used for creating a resource or performing an action."""
    delete: builtins.str
    """Maps to HTTP DELETE. Used for deleting a resource."""
    patch: builtins.str
    """Maps to HTTP PATCH. Used for updating a resource."""
    body: builtins.str
    """The name of the request field whose value is mapped to the HTTP request
    body, or `*` for mapping all request fields not captured by the path
    pattern to the HTTP body, or omitted for not having any HTTP request body.

    NOTE: the referred field must be present at the top-level of the request
    message type.
    """
    response_body: builtins.str
    """Optional. The name of the response field whose value is mapped to the HTTP
    response body. When omitted, the entire response message will be used
    as the HTTP response body.

    NOTE: The referred field must be present at the top-level of the response
    message type.
    """
    @property
    def custom(self) -> Global___CustomHttpPattern:
        """The custom pattern is used for specifying an HTTP method that is not
        included in the `pattern` field, such as HEAD, or "*" to leave the
        HTTP method unspecified for this rule. The wild-card rule is useful
        for services that provide content to Web (HTML) clients.
        """

    @property
    def additional_bindings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___HttpRule]:
        """Additional HTTP bindings for the selector. Nested bindings must
        not contain an `additional_bindings` field themselves (that is,
        the nesting may only be one level deep).
        """

    def __init__(
        self,
        *,
        selector: builtins.str | None = ...,
        get: builtins.str | None = ...,
        put: builtins.str | None = ...,
        post: builtins.str | None = ...,
        delete: builtins.str | None = ...,
        patch: builtins.str | None = ...,
        custom: Global___CustomHttpPattern | None = ...,
        body: builtins.str | None = ...,
        response_body: builtins.str | None = ...,
        additional_bindings: collections.abc.Iterable[Global___HttpRule] | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["custom", b"custom", "delete", b"delete", "get", b"get", "patch", b"patch", "pattern", b"pattern", "post", b"post", "put", b"put"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["additional_bindings", b"additional_bindings", "body", b"body", "custom", b"custom", "delete", b"delete", "get", b"get", "patch", b"patch", "pattern", b"pattern", "post", b"post", "put", b"put", "response_body", b"response_body", "selector", b"selector"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_pattern: typing_extensions.TypeAlias = typing.Literal["get", "put", "post", "delete", "patch", "custom"]
    _WhichOneofArgType_pattern: typing_extensions.TypeAlias = typing.Literal["pattern", b"pattern"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType_pattern) -> _WhichOneofReturnType_pattern | None: ...

Global___HttpRule: typing_extensions.TypeAlias = HttpRule

@typing.final
class CustomHttpPattern(google.protobuf.message.Message):
    """A custom pattern is used for defining custom HTTP verb."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KIND_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    kind: builtins.str
    """The name of this custom HTTP verb."""
    path: builtins.str
    """The path matched by this custom verb."""
    def __init__(
        self,
        *,
        kind: builtins.str | None = ...,
        path: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["kind", b"kind", "path", b"path"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CustomHttpPattern: typing_extensions.TypeAlias = CustomHttpPattern



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import galleries_pb2
import grpc
import grpc.aio
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class GalleriesStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetGallery: grpc.UnaryUnaryMultiCallable[galleries_pb2.GetGalleryReq, galleries_pb2.PhotoGallery]
    """Get a specific gallery by ID"""
    AddPhotoToGallery: grpc.UnaryUnaryMultiCallable[galleries_pb2.AddPhotoToGalleryReq, galleries_pb2.PhotoGallery]
    """Add a photo to your gallery (appended to end)"""
    RemovePhotoFromGallery: grpc.UnaryUnaryMultiCallable[galleries_pb2.RemovePhotoFromGalleryReq, galleries_pb2.PhotoGallery]
    """Remove a photo from your gallery"""
    MovePhoto: grpc.UnaryUnaryMultiCallable[galleries_pb2.MovePhotoReq, galleries_pb2.PhotoGallery]
    """Move a photo to a new position in the gallery"""
    UpdatePhotoCaption: grpc.UnaryUnaryMultiCallable[galleries_pb2.UpdatePhotoCaptionReq, galleries_pb2.PhotoGallery]
    """Update the caption of a specific photo"""
    GetGalleryEditInfo: grpc.UnaryUnaryMultiCallable[galleries_pb2.GetGalleryEditInfoReq, galleries_pb2.GetGalleryEditInfoRes]
    """Get edit info for a gallery you own (e.g., max_photos)"""

class GalleriesServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetGallery(
        self,
        request: galleries_pb2.GetGalleryReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> galleries_pb2.PhotoGallery:
        """Get a specific gallery by ID"""

    @abc.abstractmethod
    def AddPhotoToGallery(
        self,
        request: galleries_pb2.AddPhotoToGalleryReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> galleries_pb2.PhotoGallery:
        """Add a photo to your gallery (appended to end)"""

    @abc.abstractmethod
    def RemovePhotoFromGallery(
        self,
        request: galleries_pb2.RemovePhotoFromGalleryReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> galleries_pb2.PhotoGallery:
        """Remove a photo from your gallery"""

    @abc.abstractmethod
    def MovePhoto(
        self,
        request: galleries_pb2.MovePhotoReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> galleries_pb2.PhotoGallery:
        """Move a photo to a new position in the gallery"""

    @abc.abstractmethod
    def UpdatePhotoCaption(
        self,
        request: galleries_pb2.UpdatePhotoCaptionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> galleries_pb2.PhotoGallery:
        """Update the caption of a specific photo"""

    @abc.abstractmethod
    def GetGalleryEditInfo(
        self,
        request: galleries_pb2.GetGalleryEditInfoReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> galleries_pb2.GetGalleryEditInfoRes:
        """Get edit info for a gallery you own (e.g., max_photos)"""

def add_GalleriesServicer_to_server(servicer: GalleriesServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: postal_verification.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19postal_verification.proto\x12$org.couchers.api.postal_verification\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"\x87\x01\n\rPostalAddress\x12\x16\n\x0e\x61\x64\x64ress_line_1\x18\x01 \x01(\t\x12\x16\n\x0e\x61\x64\x64ress_line_2\x18\x02 \x01(\t\x12\x0c\n\x04\x63ity\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x13\n\x0bpostal_code\x18\x05 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x06 \x01(\t\"e\n\x1dInitiatePostalVerificationReq\x12\x44\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x33.org.couchers.api.postal_verification.PostalAddress\"\xb6\x01\n\x1dInitiatePostalVerificationRes\x12&\n\x1epostal_verification_attempt_id\x18\x01 \x01(\x03\x12N\n\x11\x63orrected_address\x18\x02 \x01(\x0b\x32\x33.org.couchers.api.postal_verification.PostalAddress\x12\x1d\n\x15\x61\x64\x64ress_was_corrected\x18\x03 \x01(\x08\"A\n\x17\x43onfirmPostalAddressReq\x12&\n\x1epostal_verification_attempt_id\x18\x01 \x01(\x03\"\x19\n\x17\x43onfirmPostalAddressRes\"H\n\x1eGetPostalVerificationStatusReq\x12&\n\x1epostal_verification_attempt_id\x18\x01 \x01(\x03\"\xdd\x03\n\x1eGetPostalVerificationStatusRes\x12\x1f\n\x17has_postal_verification\x18\x01 \x01(\x08\x12\x1a\n\x12has_active_attempt\x18\x02 \x01(\x08\x12&\n\x1epostal_verification_attempt_id\x18\x03 \x01(\x03\x12N\n\x06status\x18\x04 \x01(\x0e\x32>.org.couchers.api.postal_verification.PostalVerificationStatus\x12\x44\n\x07\x61\x64\x64ress\x18\x05 \x01(\x0b\x32\x33.org.couchers.api.postal_verification.PostalAddress\x12+\n\x07\x63reated\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10postcard_sent_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\x18\x63\x61n_initiate_new_attempt\x18\x08 \x01(\x08\x12;\n\x17next_attempt_allowed_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"#\n\x13VerifyPostalCodeReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"B\n\x13VerifyPostalCodeRes\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1a\n\x12remaining_attempts\x18\x02 \x01(\x05\"E\n\x1b\x43\x61ncelPostalVerificationReq\x12&\n\x1epostal_verification_attempt_id\x18\x01 \x01(\x03\"#\n!ListPostalVerificationAttemptsReq\"}\n!ListPostalVerificationAttemptsRes\x12X\n\x08\x61ttempts\x18\x01 \x03(\x0b\x32\x46.org.couchers.api.postal_verification.PostalVerificationAttemptSummary\"\xbe\x02\n PostalVerificationAttemptSummary\x12&\n\x1epostal_verification_attempt_id\x18\x01 \x01(\x03\x12N\n\x06status\x18\x02 \x01(\x0e\x32>.org.couchers.api.postal_verification.PostalVerificationStatus\x12\x44\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0b\x32\x33.org.couchers.api.postal_verification.PostalAddress\x12+\n\x07\x63reated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bverified_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*\xdc\x02\n\x18PostalVerificationStatus\x12&\n\"POSTAL_VERIFICATION_STATUS_UNKNOWN\x10\x00\x12;\n7POSTAL_VERIFICATION_STATUS_PENDING_ADDRESS_CONFIRMATION\x10\x01\x12*\n&POSTAL_VERIFICATION_STATUS_IN_PROGRESS\x10\x02\x12\x34\n0POSTAL_VERIFICATION_STATUS_AWAITING_VERIFICATION\x10\x03\x12(\n$POSTAL_VERIFICATION_STATUS_SUCCEEDED\x10\x04\x12%\n!POSTAL_VERIFICATION_STATUS_FAILED\x10\x05\x12(\n$POSTAL_VERIFICATION_STATUS_CANCELLED\x10\x06\x32\xc9\x07\n\x12PostalVerification\x12\xa8\x01\n\x1aInitiatePostalVerification\x12\x43.org.couchers.api.postal_verification.InitiatePostalVerificationReq\x1a\x43.org.couchers.api.postal_verification.InitiatePostalVerificationRes\"\x00\x12\x96\x01\n\x14\x43onfirmPostalAddress\x12=.org.couchers.api.postal_verification.ConfirmPostalAddressReq\x1a=.org.couchers.api.postal_verification.ConfirmPostalAddressRes\"\x00\x12\xab\x01\n\x1bGetPostalVerificationStatus\x12\x44.org.couchers.api.postal_verification.GetPostalVerificationStatusReq\x1a\x44.org.couchers.api.postal_verification.GetPostalVerificationStatusRes\"\x00\x12\x8a\x01\n\x10VerifyPostalCode\x12\x39.org.couchers.api.postal_verification.VerifyPostalCodeReq\x1a\x39.org.couchers.api.postal_verification.VerifyPostalCodeRes\"\x00\x12w\n\x18\x43\x61ncelPostalVerification\x12\x41.org.couchers.api.postal_verification.CancelPostalVerificationReq\x1a\x16.google.protobuf.Empty\"\x00\x12\xb4\x01\n\x1eListPostalVerificationAttempts\x12G.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq\x1aG.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'postal_verification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_POSTALVERIFICATION']._loaded_options = None
  _globals['_POSTALVERIFICATION']._serialized_options = b'\210\265\030\003'
  _globals['_POSTALVERIFICATIONSTATUS']._serialized_start=1884
  _globals['_POSTALVERIFICATIONSTATUS']._serialized_end=2232
  _globals['_POSTALADDRESS']._serialized_start=149
  _globals['_POSTALADDRESS']._serialized_end=284
  _globals['_INITIATEPOSTALVERIFICATIONREQ']._serialized_start=286
  _globals['_INITIATEPOSTALVERIFICATIONREQ']._serialized_end=387
  _globals['_INITIATEPOSTALVERIFICATIONRES']._serialized_start=390
  _globals['_INITIATEPOSTALVERIFICATIONRES']._serialized_end=572
  _globals['_CONFIRMPOSTALADDRESSREQ']._serialized_start=574
  _globals['_CONFIRMPOSTALADDRESSREQ']._serialized_end=639
  _globals['_CONFIRMPOSTALADDRESSRES']._serialized_start=641
  _globals['_CONFIRMPOSTALADDRESSRES']._serialized_end=666
  _globals['_GETPOSTALVERIFICATIONSTATUSREQ']._serialized_start=668
  _globals['_GETPOSTALVERIFICATIONSTATUSREQ']._serialized_end=740
  _globals['_GETPOSTALVERIFICATIONSTATUSRES']._serialized_start=743
  _globals['_GETPOSTALVERIFICATIONSTATUSRES']._serialized_end=1220
  _globals['_VERIFYPOSTALCODEREQ']._serialized_start=1222
  _globals['_VERIFYPOSTALCODEREQ']._serialized_end=1257
  _globals['_VERIFYPOSTALCODERES']._serialized_start=1259
  _globals['_VERIFYPOSTALCODERES']._serialized_end=1325
  _globals['_CANCELPOSTALVERIFICATIONREQ']._serialized_start=1327
  _globals['_CANCELPOSTALVERIFICATIONREQ']._serialized_end=1396
  _globals['_LISTPOSTALVERIFICATIONATTEMPTSREQ']._serialized_start=1398
  _globals['_LISTPOSTALVERIFICATIONATTEMPTSREQ']._serialized_end=1433
  _globals['_LISTPOSTALVERIFICATIONATTEMPTSRES']._serialized_start=1435
  _globals['_LISTPOSTALVERIFICATIONATTEMPTSRES']._serialized_end=1560
  _globals['_POSTALVERIFICATIONATTEMPTSUMMARY']._serialized_start=1563
  _globals['_POSTALVERIFICATIONATTEMPTSUMMARY']._serialized_end=1881
  _globals['_POSTALVERIFICATION']._serialized_start=2235
  _globals['_POSTALVERIFICATION']._serialized_end=3204
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: resources.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fresources.proto\x12\x16org.couchers.resources\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"0\n\x14GetTermsOfServiceRes\x12\x18\n\x10terms_of_service\x18\x01 \x01(\t\"H\n\x12\x43ommunityGuideline\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tguideline\x18\x02 \x01(\t\x12\x10\n\x08icon_svg\x18\x03 \x01(\t\"e\n\x19GetCommunityGuidelinesRes\x12H\n\x14\x63ommunity_guidelines\x18\x01 \x03(\x0b\x32*.org.couchers.resources.CommunityGuideline\"&\n\x06Region\x12\x0e\n\x06\x61lpha3\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"@\n\rGetRegionsRes\x12/\n\x07regions\x18\x01 \x03(\x0b\x32\x1e.org.couchers.resources.Region\"&\n\x08Language\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"F\n\x0fGetLanguagesRes\x12\x33\n\tlanguages\x18\x01 \x03(\x0b\x32 .org.couchers.resources.Language\"E\n\x05\x42\x61\x64ge\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\"=\n\x0cGetBadgesRes\x12-\n\x06\x62\x61\x64ges\x18\x01 \x03(\x0b\x32\x1d.org.couchers.resources.Badge2\xc4\x03\n\tResources\x12[\n\x11GetTermsOfService\x12\x16.google.protobuf.Empty\x1a,.org.couchers.resources.GetTermsOfServiceRes\"\x00\x12\x65\n\x16GetCommunityGuidelines\x12\x16.google.protobuf.Empty\x1a\x31.org.couchers.resources.GetCommunityGuidelinesRes\"\x00\x12M\n\nGetRegions\x12\x16.google.protobuf.Empty\x1a%.org.couchers.resources.GetRegionsRes\"\x00\x12Q\n\x0cGetLanguages\x12\x16.google.protobuf.Empty\x1a\'.org.couchers.resources.GetLanguagesRes\"\x00\x12K\n\tGetBadges\x12\x16.google.protobuf.Empty\x1a$.org.couchers.resources.GetBadgesRes\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'resources_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RESOURCES']._loaded_options = None
  _globals['_RESOURCES']._serialized_options = b'\210\265\030\001'
  _globals['_GETTERMSOFSERVICERES']._serialized_start=91
  _globals['_GETTERMSOFSERVICERES']._serialized_end=139
  _globals['_COMMUNITYGUIDELINE']._serialized_start=141
  _globals['_COMMUNITYGUIDELINE']._serialized_end=213
  _globals['_GETCOMMUNITYGUIDELINESRES']._serialized_start=215
  _globals['_GETCOMMUNITYGUIDELINESRES']._serialized_end=316
  _globals['_REGION']._serialized_start=318
  _globals['_REGION']._serialized_end=356
  _globals['_GETREGIONSRES']._serialized_start=358
  _globals['_GETREGIONSRES']._serialized_end=422
  _globals['_LANGUAGE']._serialized_start=424
  _globals['_LANGUAGE']._serialized_end=462
  _globals['_GETLANGUAGESRES']._serialized_start=464
  _globals['_GETLANGUAGESRES']._serialized_end=534
  _globals['_BADGE']._serialized_start=536
  _globals['_BADGE']._serialized_end=605
  _globals['_GETBADGESRES']._serialized_start=607
  _globals['_GETBADGESRES']._serialized_end=668
  _globals['_RESOURCES']._serialized_start=671
  _globals['_RESOURCES']._serialized_end=1123
# @@protoc_insertion_point(module_scope)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import collections.abc


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import conversations_pb2
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class ConversationsStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ListGroupChats: grpc.UnaryUnaryMultiCallable[conversations_pb2.ListGroupChatsReq, conversations_pb2.ListGroupChatsRes]
    """Retrieves list of group chats (ordered by last message), paginated"""
    GetGroupChat: grpc.UnaryUnaryMultiCallable[conversations_pb2.GetGroupChatReq, conversations_pb2.GroupChat]
    """Retrieves group chat info by id"""
    GetDirectMessage: grpc.UnaryUnaryMultiCallable[conversations_pb2.GetDirectMessageReq, conversations_pb2.GroupChat]
    """Retrieves group chat info for the unique (if any) direct message with a
    given user

    Raises: NOT_FOUND if there is no such direct message thread
    """
    GetUpdates: grpc.UnaryUnaryMultiCallable[conversations_pb2.GetUpdatesReq, conversations_pb2.GetUpdatesRes]
    """Returns all new messages (aka updates) since a given message id"""
    GetGroupChatMessages: grpc.UnaryUnaryMultiCallable[conversations_pb2.GetGroupChatMessagesReq, conversations_pb2.GetGroupChatMessagesRes]
    """Retrieves messages in group chat, paginated"""
    MarkLastSeenGroupChat: grpc.UnaryUnaryMultiCallable[conversations_pb2.MarkLastSeenGroupChatReq, google.protobuf.empty_pb2.Empty]
    """Marks the last message that has been seen in this group chat"""
    MuteGroupChat: grpc.UnaryUnaryMultiCallable[conversations_pb2.MuteGroupChatReq, google.protobuf.empty_pb2.Empty]
    """Mutes or unmutes a group chat
    when muted, you don't get notifications from that group chat
    """
    SetGroupChatArchiveStatus: grpc.UnaryUnaryMultiCallable[conversations_pb2.SetGroupChatArchiveStatusReq, conversations_pb2.SetGroupChatArchiveStatusRes]
    """Archives or unarchives a group chat"""
    CreateGroupChat: grpc.UnaryUnaryMultiCallable[conversations_pb2.CreateGroupChatReq, conversations_pb2.GroupChat]
    """Creates a new group chat"""
    EditGroupChat: grpc.UnaryUnaryMultiCallable[conversations_pb2.EditGroupChatReq, google.protobuf.empty_pb2.Empty]
    """Modifies group chat"""
    InviteToGroupChat: grpc.UnaryUnaryMultiCallable[conversations_pb2.InviteToGroupChatReq, google.protobuf.empty_pb2.Empty]
    """Invite a person to a chat"""
    MakeGroupChatAdmin: grpc.UnaryUnaryMultiCallable[conversations_pb2.MakeGroupChatAdminReq, google.protobuf.empty_pb2.Empty]
    """Make a user an admin of a group chat"""
    RemoveGroupChatUser: grpc.UnaryUnaryMultiCallable[conversations_pb2.RemoveGroupChatUserReq, google.protobuf.empty_pb2.Empty]
    """Remove a user in a group chat."""
    RemoveGroupChatAdmin: grpc.UnaryUnaryMultiCallable[conversations_pb2.RemoveGroupChatAdminReq, google.protobuf.empty_pb2.Empty]
    """Remove a user from admin in group chat. TODO: Only original creator can do this"""
    SendMessage: grpc.UnaryUnaryMultiCallable[conversations_pb2.SendMessageReq, google.protobuf.empty_pb2.Empty]
    """Send a message to a group chat"""
    SendDirectMessage: grpc.UnaryUnaryMultiCallable[conversations_pb2.SendDirectMessageReq, conversations_pb2.SendDirectMessageRes]
    """Sends a direct message by either creating or using an existing DM chat"""
    LeaveGroupChat: grpc.UnaryUnaryMultiCallable[conversations_pb2.LeaveGroupChatReq, google.protobuf.empty_pb2.Empty]
    """Leave a group chat"""
    SearchMessages: grpc.UnaryUnaryMultiCallable[conversations_pb2.SearchMessagesReq, conversations_pb2.SearchMessagesRes]
    """Search messages by string"""

class ConversationsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ListGroupChats(
        self,
        request: conversations_pb2.ListGroupChatsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> conversations_pb2.ListGroupChatsRes:
        """Retrieves list of group chats (ordered by last message), paginated"""

    @abc.abstractmethod
    def GetGroupChat(
        self,
        request: conversations_pb2.GetGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> conversations_pb2.GroupChat:
        """Retrieves group chat info by id"""

    @abc.abstractmethod
    def GetDirectMessage(
        self,
        request: conversations_pb2.GetDirectMessageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> conversations_pb2.GroupChat:
        """Retrieves group chat info for the unique (if any) direct message with a
        given user

        Raises: NOT_FOUND if there is no such direct message thread
        """

    @abc.abstractmethod
    def GetUpdates(
        self,
        request: conversations_pb2.GetUpdatesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> conversations_pb2.GetUpdatesRes:
        """Returns all new messages (aka updates) since a given message id"""

    @abc.abstractmethod
    def GetGroupChatMessages(
        self,
        request: conversations_pb2.GetGroupChatMessagesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> conversations_pb2.GetGroupChatMessagesRes:
        """Retrieves messages in group chat, paginated"""

    @abc.abstractmethod
    def MarkLastSeenGroupChat(
        self,
        request: conversations_pb2.MarkLastSeenGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Marks the last message that has been seen in this group chat"""

    @abc.abstractmethod
    def MuteGroupChat(
        self,
        request: conversations_pb2.MuteGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Mutes or unmutes a group chat
        when muted, you don't get notifications from that group chat
        """

    @abc.abstractmethod
    def SetGroupChatArchiveStatus(
        self,
        request: conversations_pb2.SetGroupChatArchiveStatusReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> conversations_pb2.SetGroupChatArchiveStatusRes:
        """Archives or unarchives a group chat"""

    @abc.abstractmethod
    def CreateGroupChat(
        self,
        request: conversations_pb2.CreateGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> conversations_pb2.GroupChat:
        """Creates a new group chat"""

    @abc.abstractmethod
    def EditGroupChat(
        self,
        request: conversations_pb2.EditGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Modifies group chat"""

    @abc.abstractmethod
    def InviteToGroupChat(
        self,
        request: conversations_pb2.InviteToGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Invite a person to a chat"""

    @abc.abstractmethod
    def MakeGroupChatAdmin(
        self,
        request: conversations_pb2.MakeGroupChatAdminReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Make a user an admin of a group chat"""

    @abc.abstractmethod
    def RemoveGroupChatUser(
        self,
        request: conversations_pb2.RemoveGroupChatUserReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Remove a user in a group chat."""

    @abc.abstractmethod
    def RemoveGroupChatAdmin(
        self,
        request: conversations_pb2.RemoveGroupChatAdminReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Remove a user from admin in group chat. TODO: Only original creator can do this"""

    @abc.abstractmethod
    def SendMessage(
        self,
        request: conversations_pb2.SendMessageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Send a message to a group chat"""

    @abc.abstractmethod
    def SendDirectMessage(
        self,
        request: conversations_pb2.SendDirectMessageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> conversations_pb2.SendDirectMessageRes:
        """Sends a direct message by either creating or using an existing DM chat"""

    @abc.abstractmethod
    def LeaveGroupChat(
        self,
        request: conversations_pb2.LeaveGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Leave a group chat"""

    @abc.abstractmethod
    def SearchMessages(
        self,
        request: conversations_pb2.SearchMessagesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> conversations_pb2.SearchMessagesRes:
        """Search messages by string"""

def add_ConversationsServicer_to_server(servicer: ConversationsServicer, server: grpc.Server) -> None: ...
